==> birdtray_1.8.0+ds.orig.tar.xz: birdtray-1.8.0/src/translations/installer_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>WindowsInstaller</name>
    <message>
        <source>__LANGUAGE_NAME__</source>
        <translatorcomment>This must be the name of one of the NSIS translation files at https://sourceforge.net/p/nsis/code/HEAD/tree/NSIS/trunk/Contrib/Language%20files/ without the file extension.</translatorcomment>
        <translation>English</translation>
    </message>
    <message>
        <source>BirdtraySectionDescription</source>
        <translation>A free system tray notification for new mail for Thunderbird.</translation>
    </message>
    <message>
        <source>WinIntegrationSectionName</source>
        <translation>Windows integration</translation>
    </message>
    <message>
        <source>WinIntegrationGroupDescription</source>
        <translation>Select how to integrate the program in Windows.</translation>
    </message>
    <message>
        <source>AutoRunSectionName</source>
        <translation>AutoRun</translation>
    </message>
    <message>
        <source>AutoRunDescription</source>
        <translation>Automatically start ${PRODUCT_NAME} after login.</translation>
    </message>
    <message>
        <source>AutoCheckUpdateSectionName</source>
        <translation>Auto Update-Check</translation>
    </message>
    <message>
        <source>AutoCheckUpdateDescription</source>
        <translation>Automatically search for updates of ${PRODUCT_NAME} at startup.</translation>
    </message>
    <message>
        <source>ProgramGroupSectionName</source>
        <translation>Program Group Entry</translation>
    </message>
    <message>
        <source>ProgramGroupDescription</source>
        <translation>Create a ${PRODUCT_NAME} program group under Start Menu > Programs.</translation>
    </message>
    <message>
        <source>DesktopEntrySectionName</source>
        <translation>Desktop Entry</translation>
    </message>
    <message>
        <source>DesktopEntryDescription</source>
        <translation>Create a ${PRODUCT_NAME} icon on the Desktop.</translation>
    </message>
    <message>
        <source>StartMenuSectionName</source>
        <translation>Start Menu Entry</translation>
    </message>
    <message>
        <source>StartMenuDescription</source>
        <translation>Create a ${PRODUCT_NAME} icon in the Start Menu.</translation>
    </message>
    <message>
        <source>TranslationsSectionName</source>
        <translation>Translations</translation>
    </message>
    <message>
        <source>TranslationsDescription</source>
        <translation>Select translations for ${PRODUCT_NAME}. ${PRODUCT_NAME} will choose a translation based on the system language.</translation>
    </message>
    <message>
        <source>UserSettingsSectionName</source>
        <translation>${PRODUCT_NAME} User Settings</translation>
    </message>
    <message>
        <source>UserSettingsDescription</source>
        <translation>Your settings and configuration made within ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>LicenseStartMenuLinkName</source>
        <translation>License Agreement</translation>
    </message>
    <message>
        <source>FinishPageRunBirdtray</source>
        <translation>Start ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallerConfirmation</source>
        <translation>Click uninstall to begin the process.</translation>
    </message>
    <message>
        <source>UninstallPreviousVersion</source>
        <translation>Uninstalling previous version of ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallPreviousVersionError</source>
        <translation>Uninstalling the old ${PRODUCT_NAME} installation failed! Continuing will delete EVERYTHING in $3.</translation>
    </message>
    <message>
        <source>UninstallExecutionError</source>
        <translation>Error executing uninstaller.</translation>
    </message>
    <message>
        <source>StopBirdtray</source>
        <translation>${PRODUCT_NAME} is currently running. Press OK to stop ${PRODUCT_NAME} to continue with the installation.</translation>
    </message>
    <message>
        <source>StoppingBirdtray</source>
        <translation>Closing process ${EXE_NAME}</translation>
    </message>
    <message>
        <source>StopBirdtrayError</source>
        <translation>Failed to close ${PRODUCT_NAME}. Please retry or quit ${PRODUCT_NAME} manually to continue with the installation.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstall</source>
        <translation>${PRODUCT_NAME} is currently running. Press OK to stop ${PRODUCT_NAME} to continue with the uninstall.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstallError</source>
        <translation>Failed to close ${PRODUCT_NAME}. Please retry or quit ${PRODUCT_NAME} manually to continue with the uninstall.</translation>
    </message>
    <message>
        <source>SetupAlreadyRunning</source>
        <translation>The setup of ${PRODUCT_NAME} is already running.$\r$\nPlease, close all instances of it and click Retry to continue, or Cancel to exit.</translation>
    </message>
    <message>
        <source>UninstallAlreadyRunning</source>
        <translation>The uninstall of ${PRODUCT_NAME} is already running.$\r$\n Please, close all instances of it and click Retry to continue, or Cancel to exit.</translation>
    </message>
    <message>
        <source>BadInstallPath</source>
        <translation>The install path must not contain any of$\r$\n${BAD_PATH_CHARS}.</translation>
    </message>
    <message>
        <source>InstallPathContainsPreviousVersion</source>
        <translation>The install path contains a previously installed ${PRODUCT_NAME} version, which will be replaced.</translation>
    </message>
    <message>
        <source>InstallPathNotEmpty</source>
        <translation>The install path is not empty, but it doesn't look like it contains a previous ${PRODUCT_NAME} installation. The content will get overwritten.</translation>
    </message>
    <message>
        <source>CurrentUserOnly</source>
        <translation>$0 (current user only)</translation>
    </message>
    <message>
        <source>InstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} could not be fully installed.$\r$\n\Please, restart Windows and run the setup program again.</translation>
    </message>
    <message>
        <source>InstallFailedCauseUninstallerFailed</source>
        <translation>${PRODUCT_NAME} could not be fully installed.$\r$\n\Please, restart Windows and run the setup program again.</translation>
    </message>
    <message>
        <source>UninstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} could not be fully uninstalled.$\r$\nPlease, restart Windows and run the uninstaller again.</translation>
    </message>
    <message>
        <source>FileDeleteErrorDialog</source>
        <translation>Error deleting file:$\r$\n$\r$\n$0$\r$\n$\r$\nClick Retry to try again, or$\r$\nCancel to stop the uninstall.</translation>
    </message>
    <message>
        <source>FileDeleteError</source>
        <translation>Error deleting file $0</translation>
    </message>
    <message>
        <source>Install64On32BitWarning</source>
        <translation>You are about to install the 32-bit version of ${PRODUCT_NAME} on your 64-bit Windows. There is a 64-bit version of ${PRODUCT_NAME} available for download.</translation>
    </message>
    <message>
        <source>Install32On64BitError</source>
        <translation>This installer contains the 64-bit version of ${PRODUCT_NAME}. Your computer is running a 32-bit version of Windows, which can not execute 64-bit programs. Please download the 32-bit installer of ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>UnsupportedWindowsVersionError</source>
        <translation>This program requires at least Windows ${MIN_WINDOWS_VER}.</translation>
    </message>
    <message>
        <source>UninstallerAborted</source>
        <translation>Uninstalling ${PRODUCT_NAME} has been aborted. Please try again later.</translation>
    </message>
    <message>
        <source>SettingsLink</source>
        <translation>${PRODUCT_NAME} settings</translation>
    </message>
    <message>
        <source>UninstallRestartAsUserQuestion</source>
        <translation>The uninstaller is started with administrator privileges but there seems to be no ${PRODUCT_NAME} installation for the administrator. Do you want to restart the uninstaller without admin privileges?</translation>
    </message>
    <message>
        <source>OpenUrl</source>
        <translation>Opening $0 in default browser...</translation>
    </message>
    <message>
        <source>MissingVcRuntime</source>
        <translation>Unable to find Visual C++ Runtime ${ARCH}.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Dialog</source>
        <translation>The following required component was not found on this computer:$\r$\nVisual C++ Runtime ${ARCH}$\r$\nDo you want to download the installer for the component?</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Retry</source>
        <translation>Once the download completes, please execute the downloaded installer. When the installer is finished, press OK to check the installation status again.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Found</source>
        <translation>The required component was successfully detected on your computer.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_StillNotFound</source>
        <translation>The required component was not found on your computer. Please search online for Visual C++ ${ARCH} downloads for Visual Studio 2015 and higher.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRun</source>
        <translation>${PRODUCT_NAME} will not be able to run.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRunDialog</source>
        <translation>${PRODUCT_NAME} will not be able to start because a required component is missing.</translation>
    </message>
    <message>
        <source>Lang_en</source>
        <translation>English</translation>
    </message>
    <message>
        <source>Lang_de</source>
        <translation>German</translation>
    </message>
    <message>
        <source>Lang_nl</source>
        <translation>Dutch</translation>
    </message>
    <message>
        <source>Lang_it</source>
        <translation>Italian</translation>
    </message>
</context>
</TS>

==> birdtray_1.8.1+ds.orig.tar.xz: birdtray-1.8.1/src/translations/installer_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>WindowsInstaller</name>
    <message>
        <source>__LANGUAGE_NAME__</source>
        <translatorcomment>This must be the name of one of the NSIS translation files at https://sourceforge.net/p/nsis/code/HEAD/tree/NSIS/trunk/Contrib/Language%20files/ without the file extension.</translatorcomment>
        <translation>English</translation>
    </message>
    <message>
        <source>BirdtraySectionDescription</source>
        <translation>A free system tray notification for new mail for Thunderbird.</translation>
    </message>
    <message>
        <source>WinIntegrationSectionName</source>
        <translation>Windows integration</translation>
    </message>
    <message>
        <source>WinIntegrationGroupDescription</source>
        <translation>Select how to integrate the program in Windows.</translation>
    </message>
    <message>
        <source>AutoRunSectionName</source>
        <translation>AutoRun</translation>
    </message>
    <message>
        <source>AutoRunDescription</source>
        <translation>Automatically start ${PRODUCT_NAME} after login.</translation>
    </message>
    <message>
        <source>AutoCheckUpdateSectionName</source>
        <translation>Auto Update-Check</translation>
    </message>
    <message>
        <source>AutoCheckUpdateDescription</source>
        <translation>Automatically search for updates of ${PRODUCT_NAME} at startup.</translation>
    </message>
    <message>
        <source>ProgramGroupSectionName</source>
        <translation>Program Group Entry</translation>
    </message>
    <message>
        <source>ProgramGroupDescription</source>
        <translation>Create a ${PRODUCT_NAME} program group under Start Menu > Programs.</translation>
    </message>
    <message>
        <source>DesktopEntrySectionName</source>
        <translation>Desktop Entry</translation>
    </message>
    <message>
        <source>DesktopEntryDescription</source>
        <translation>Create a ${PRODUCT_NAME} icon on the Desktop.</translation>
    </message>
    <message>
        <source>StartMenuSectionName</source>
        <translation>Start Menu Entry</translation>
    </message>
    <message>
        <source>StartMenuDescription</source>
        <translation>Create a ${PRODUCT_NAME} icon in the Start Menu.</translation>
    </message>
    <message>
        <source>TranslationsSectionName</source>
        <translation>Translations</translation>
    </message>
    <message>
        <source>TranslationsDescription</source>
        <translation>Select translations for ${PRODUCT_NAME}. ${PRODUCT_NAME} will choose a translation based on the system language.</translation>
    </message>
    <message>
        <source>UserSettingsSectionName</source>
        <translation>${PRODUCT_NAME} User Settings</translation>
    </message>
    <message>
        <source>UserSettingsDescription</source>
        <translation>Your settings and configuration made within ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>LicenseStartMenuLinkName</source>
        <translation>License Agreement</translation>
    </message>
    <message>
        <source>FinishPageRunBirdtray</source>
        <translation>Start ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallerConfirmation</source>
        <translation>Click uninstall to begin the process.</translation>
    </message>
    <message>
        <source>UninstallPreviousVersion</source>
        <translation>Uninstalling previous version of ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallPreviousVersionError</source>
        <translation>Uninstalling the old ${PRODUCT_NAME} installation failed! Continuing will delete EVERYTHING in $3.</translation>
    </message>
    <message>
        <source>UninstallExecutionError</source>
        <translation>Error executing uninstaller.</translation>
    </message>
    <message>
        <source>StopBirdtray</source>
        <translation>${PRODUCT_NAME} is currently running. Press OK to stop ${PRODUCT_NAME} to continue with the installation.</translation>
    </message>
    <message>
        <source>StoppingBirdtray</source>
        <translation>Closing process ${EXE_NAME}</translation>
    </message>
    <message>
        <source>StopBirdtrayError</source>
        <translation>Failed to close ${PRODUCT_NAME}. Please retry or quit ${PRODUCT_NAME} manually to continue with the installation.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstall</source>
        <translation>${PRODUCT_NAME} is currently running. Press OK to stop ${PRODUCT_NAME} to continue with the uninstall.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstallError</source>
        <translation>Failed to close ${PRODUCT_NAME}. Please retry or quit ${PRODUCT_NAME} manually to continue with the uninstall.</translation>
    </message>
    <message>
        <source>SetupAlreadyRunning</source>
        <translation>The setup of ${PRODUCT_NAME} is already running.$\r$\nPlease, close all instances of it and click Retry to continue, or Cancel to exit.</translation>
    </message>
    <message>
        <source>UninstallAlreadyRunning</source>
        <translation>The uninstall of ${PRODUCT_NAME} is already running.$\r$\n Please, close all instances of it and click Retry to continue, or Cancel to exit.</translation>
    </message>
    <message>
        <source>BadInstallPath</source>
        <translation>The install path must not contain any of$\r$\n${BAD_PATH_CHARS}.</translation>
    </message>
    <message>
        <source>InstallPathContainsPreviousVersion</source>
        <translation>The install path contains a previously installed ${PRODUCT_NAME} version, which will be replaced.</translation>
    </message>
    <message>
        <source>InstallPathNotEmpty</source>
        <translation>The install path is not empty, but it doesn't look like it contains a previous ${PRODUCT_NAME} installation. The content will get overwritten.</translation>
    </message>
    <message>
        <source>CurrentUserOnly</source>
        <translation>$0 (current user only)</translation>
    </message>
    <message>
        <source>InstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} could not be fully installed.$\r$\n\Please, restart Windows and run the setup program again.</translation>
    </message>
    <message>
        <source>InstallFailedCauseUninstallerFailed</source>
        <translation>${PRODUCT_NAME} could not be fully installed.$\r$\n\Please, restart Windows and run the setup program again.</translation>
    </message>
    <message>
        <source>UninstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} could not be fully uninstalled.$\r$\nPlease, restart Windows and run the uninstaller again.</translation>
    </message>
    <message>
        <source>FileDeleteErrorDialog</source>
        <translation>Error deleting file:$\r$\n$\r$\n$0$\r$\n$\r$\nClick Retry to try again, or$\r$\nCancel to stop the uninstall.</translation>
    </message>
    <message>
        <source>FileDeleteError</source>
        <translation>Error deleting file $0</translation>
    </message>
    <message>
        <source>Install64On32BitWarning</source>
        <translation>You are about to install the 32-bit version of ${PRODUCT_NAME} on your 64-bit Windows. There is a 64-bit version of ${PRODUCT_NAME} available for download.</translation>
    </message>
    <message>
        <source>Install32On64BitError</source>
        <translation>This installer contains the 64-bit version of ${PRODUCT_NAME}. Your computer is running a 32-bit version of Windows, which can not execute 64-bit programs. Please download the 32-bit installer of ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>UnsupportedWindowsVersionError</source>
        <translation>This program requires at least Windows ${MIN_WINDOWS_VER}.</translation>
    </message>
    <message>
        <source>UninstallerAborted</source>
        <translation>Uninstalling ${PRODUCT_NAME} has been aborted. Please try again later.</translation>
    </message>
    <message>
        <source>SettingsLink</source>
        <translation>${PRODUCT_NAME} settings</translation>
    </message>
    <message>
        <source>UninstallRestartAsUserQuestion</source>
        <translation>The uninstaller is started with administrator privileges but there seems to be no ${PRODUCT_NAME} installation for the administrator. Do you want to restart the uninstaller without admin privileges?</translation>
    </message>
    <message>
        <source>OpenUrl</source>
        <translation>Opening $0 in default browser...</translation>
    </message>
    <message>
        <source>MissingVcRuntime</source>
        <translation>Unable to find Visual C++ Runtime ${ARCH}.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Dialog</source>
        <translation>The following required component was not found on this computer:$\r$\nVisual C++ Runtime ${ARCH}$\r$\nDo you want to download the installer for the component?</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Retry</source>
        <translation>Once the download completes, please execute the downloaded installer. When the installer is finished, press OK to check the installation status again.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Found</source>
        <translation>The required component was successfully detected on your computer.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_StillNotFound</source>
        <translation>The required component was not found on your computer. Please search online for Visual C++ ${ARCH} downloads for Visual Studio 2015 and higher.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRun</source>
        <translation>${PRODUCT_NAME} will not be able to run.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRunDialog</source>
        <translation>${PRODUCT_NAME} will not be able to start because a required component is missing.</translation>
    </message>
    <message>
        <source>Lang_en</source>
        <translation>English</translation>
    </message>
    <message>
        <source>Lang_de</source>
        <translation>German</translation>
    </message>
    <message>
        <source>Lang_nl</source>
        <translation>Dutch</translation>
    </message>
    <message>
        <source>Lang_it</source>
        <translation>Italian</translation>
    </message>
    <message>
        <source>Lang_ru</source>
        <translation>Russian</translation>
    </message>
    <message>
        <source>Lang_pt</source>
        <translation>Portugees</translation>
    </message>
    <message>
        <source>Lang_es</source>
        <translation>Spanish</translation>
    </message>
</context>
</TS>
